from aiida import orm, load_profile
from aiida.plugins import WorkflowFactory
from aiida_quantumespresso.common.types import ElectronicType, RelaxType
from aiida.engine import submit

load_profile()
PwRelaxWorkChain = WorkflowFactory('quantumespresso.pw.relax')


def relax():
    """Relax LiNbO3 using PBE."""
    code = orm.Code.get_from_string('pw_7.0@hlrn-gottingen')
    structure = orm.load_node('c7485666-d5e7-45a4-a1d6-51343ca0d61e')
    
    pseudo = "SSSP/1.1/PBE/precision"
        
    pw_overrides = {
        'pseudo_family': pseudo,
        'kpoints_distance':0.3,
        'meta_parameters': {
            'conv_thr_per_atom':1.0e-12,
        },
        'pw':{
            'parameters':{
                'CONTROL': {'forc_conv_thr': 5.0e-5, 'nstep':500},
                'SYSTEM': {
                    'ecutwfc':90, 
                    'ecutrho':90*12,
                },
                'ELECTRONS': {
                    'electron_maxstep':600, 
                    'mixing_beta':0.4, 
                },
                'IONS': {'bfgs_ndim':5},
                'CELL': {'press_conv_thr':0.1},
            },
            'settings':  {'cmdline':['-nk', '8']},
        },
        'metadata':{
            'options':{
                'resources':{
                    'num_machines':1,
                    'num_mpiprocs_per_machine':96,
                },
                'max_wallclock_seconds' : 12*60*60, 
                'account':'hbc00053',
            }
        }
    }

    overrides = {'base':pw_overrides, 'clean_workdir':True,}
    kwargs = {
        'code':code,
        'structure':structure, 
        'relax_type':RelaxType.POSITIONS,
        'electronic_type':ElectronicType.INSULATOR,
    } 

    builder = PwRelaxWorkChain.get_builder_from_protocol(overrides=overrides, **kwargs)
    builder.pop('base_final_scf', None)

    builder.metadata.label = 'LiNbO3'
    builder.metadata.description = f'LiNbO3 relaxation with PBE'

    calc = submit(builder)
    print(f'# PBE : {calc.pk}')


if __name__ == '__main__':
    """Run the script"""
    relax()