import time
from aiida import orm, load_profile
from aiida.plugins import WorkflowFactory
from aiida.engine import submit

load_profile()

AverageWorkChain = WorkflowFactory('vibroscopy.spectra.intensities_average')


def average_spectra(vibro_pk, functional):
    """Launch a powder average spectra calculation."""
    vibro = orm.load_node(vibro_pk)

    inputs = {
        'vibrational_data': vibro,
        'parameters': orm.Dict({
            'quadrature_order': 41,
            'with_nlo': True,
            'temperature': 80,  
        }),
    }

    calc = submit(AverageWorkChain, **inputs)
    print(f"{calc.pk} - {functional}")


def main():
    """Main function to be called."""
    vibro_pks = [
        '37d87bc5-c7f8-4f07-8441-3f8b996e3551',
        '0ee4d5a4-a0a7-4c2c-a158-eff100208031',
        '6b7d28aa-b2d8-44a3-8d7d-3bc1ef55d7e4',
        'b89d81ae-071e-4ccb-9efc-918d6ba5c894',
        '2ef9edad-3b16-418f-ab6a-613e32b8b2bc',
        '1975fb4f-b8a7-48e0-8294-e0b30b3cd8d4',
        'c835379a-0562-4fb8-8107-dd96c678dc9a',
    ]

    functionals = [
        'LDA',
        'PBEsol+U',
        'PBEsol',
        'PBE',
        'PBEsol+U+V',
        'HSE06',
        'PBE0',
    ]

    for pk, functional in zip(vibro_pks, functionals):
        average_spectra(pk, functional)
        time.sleep(1*60)


if __name__ == "__main__":
    main()
