from aiida import load_profile
from aiida.plugins import WorkflowFactory
from aiida.orm import *
from aiida.engine import submit

from aiida_quantumespresso.common.types import ElectronicType

import yaml

load_profile() 
WorkChain = WorkflowFactory('vibroscopy.dielectric')


# ====================== LOOK HERE ================================== #
filename = 'dielectric'
structure_pk = 'b112324b-a0ff-49b3-9356-01033e265fbe' # conventional cell
filepath = f'./{filename}.yml'
# =================================================================== #
print(f'Running with yaml configuration from: {filename} ...')


def main(overrides):
    """Submit WorkChain using overrides from a yaml file."""
    code = load_code('pw_7.2@hlrn-gottingen')
    structure = load_node(structure_pk)
    
    args = (code, structure,'precise')
    kwargs = {'electronic_type': ElectronicType.INSULATOR}

    builder = WorkChain.get_builder_from_protocol(*args, overrides=overrides, **kwargs)

    calc = submit(builder)
    kd = overrides['kpoints_parallel_distance']
    print(f'{kd} - {calc.pk} ')


if __name__ == '__main__':
    with open(filepath, 'r') as handle:
        overrides = yaml.load(handle, yaml.SafeLoader)
    
    kds = [0.3, 0.2, 0.15, 0.10, 0.075, 0.05]

    for i, kd in enumerate(kds):
        overrides['kpoints_parallel_distance'] = kd
        overrides['scf']['kpoints_distance'] = kd
        overrides['central_difference']['accuracy'] = 2
        overrides['central_difference']['electric_field_step'] = 2.5e-4
        overrides['scf']['pw']['metadata']['options']['max_wallclock_seconds'] = int(2*24*3600)

        main(overrides)
    