from aiida import load_profile
from aiida.orm import *
from aiida.engine import submit
from aiida_quantumespresso_ph.workflows.dynamical_matrix import DynamicalMatrixWorkChain

from aiida_quantumespresso.common.types import ElectronicType, RelaxType

import yaml

load_profile() 


# ====================== LOOK HERE ================================== #
filename = 'dyn_mat'
structure_pk = '5e998345-9a37-41ae-8a65-eb1587592c00' # 184939 -> 5e998345-9a37-41ae-8a65-eb1587592c00 (primitive ideal shifted 0.0005 Ang)
group_label = 'AlAs'
filepath = f'./{filename}.yml'
# =================================================================== #
print(f'Running with yaml configuration from: {filename} ...')

qpoints = KpointsData()
qpoints.set_kpoints_mesh([1,1,1])
qpoints.store()

def main(overrides, kk):
    """Submit WorkChain using overrides from a yaml file."""
    pw_code = load_code('pw_7.2_gpu@lesum-gpu')
    ph_code = load_code('ph_7.2_gpu@lesum-gpu')
    structure = load_node(structure_pk)
    
    args = (pw_code, ph_code, structure, 'precise')
    kwargs = {'electronic_type': ElectronicType.INSULATOR, 'relax_type': RelaxType.NONE}

    builder = DynamicalMatrixWorkChain.get_builder_from_protocol(*args, overrides=overrides, **kwargs)
    builder.ph_main.qpoints = qpoints
    builder.ph_main.pop('qpoints_distance')
    
    builder['relax'].pop('base_final_scf')
    
    kpoints = KpointsData()
    kpoints.set_kpoints_mesh([kk,kk,kk])
    builder.relax.base.kpoints = kpoints
    builder.relax.base.pop('kpoints_distance')
    
    group = load_group(group_label)
    calc = submit(builder)
    group.add_nodes(calc)
    
    print(f'{kk} - {calc.pk} ')


if __name__ == '__main__':
    """Execute script."""
    with open(filepath, 'r') as handle:
        overrides = yaml.load(handle, yaml.SafeLoader)
    
    kks = [5,7,10,13,20,26,39]
    
    for kk in kks:
        main(overrides, kk)