from argparse import ArgumentParser
import numpy as np
import os

parser = ArgumentParser()
parser.add_argument('-k', type=str, default="1 1 1  0 0 0",  dest="k_points")
args = parser.parse_args()

dirpath = '.'

options= { 
  "k_points" : args.k_points,
  "prefix"   : "aiida",
  "ecutwfc"  : 140,
  "outdir"   : dirpath+'/out',
  "pos_al"   : [1.4061886093753, 1.4061886093753, 1.4061886093753],
}

prefix = "mpirun -np 320 "
espresso_bin = '/home/hbiblore/builds/qe/7.2/bin/'
pw_command = prefix + espresso_bin + "pw.x -nk 16"
ph_command = prefix + espresso_bin + "ph.x -nk 16"

pw_input="""&CONTROL
   calculation='scf'
   restart_mode='from_scratch',
   prefix='{prefix}',
   pseudo_dir = './pseudo/',
   outdir='{outdir}'
   tprnfor = .true.
   tstress = .true.
/
&SYSTEM
   ecutwfc = {ecutwfc}
   ibrav = 0
   nat = 2
   ntyp = 2
/
&ELECTRONS
 conv_thr =  8.0d-18
/
ATOMIC_SPECIES
  Al  26.9815 Al.upf
  As  74.9216 As.upf
ATOMIC_POSITIONS  angstrom
  As  0.0 0.0 0.0
  Al  {pos_al[0]} {pos_al[1]} {pos_al[2]} 
K_POINTS automatic
 {k_points} {k_points} {k_points} 0 0 0
CELL_PARAMETERS angstrom
      0.0000000000000 2.8123772187506 2.8123772187506
      2.8123772187506 0.0000000000000 2.8123772187506
      2.8123772187506 2.8123772187506 0.0000000000000
"""

ph_epsil="""AlAs at Gamma dielectric matrix
 &inputph
  tr2_ph=1.0d-21
  prefix='{prefix}'
  outdir='{outdir}'

  epsil=.true.
  trans=.false.
  zue=.false
  zeu=.false.
 /
0.0 0.0 0.0
"""

def run_command(executable_file, input_data, filebase):
  """Run an executable from the script."""
  from subprocess import Popen
  
  print("Running "+executable_file+" writing output to "+filebase+".out")

  with open(filebase+".in", 'w+') as input_f:
    input_f.write(input_data)

  command = f"{executable_file} -in {filebase}.in > {filebase}.out"
  proc = Popen(command, shell=True,)
  proc.wait()


def read_epsil(file_name):
  """Read the high-frequency dielectric tensors."""
  epsil_matrix = np.zeros((3,3))
  with open(file_name, 'r') as file:
    while True:
      line = file.readline()
      if not line:
        raise Exception("could not find Dielectric matrix in "+file_name)
      if line.find("Dielectric constant in cartesian axis") > 0 :
        file.readline() # empty line
        for ipol in range(3):
          line = file.readline()
          words = line.split()
          epsil_line = np.array([words[1], words[2], words[3]], dtype=np.float64)
          epsil_matrix[ipol] = epsil_line
        
        return epsil_matrix


# ============== Main execution of the script ================== #
# Finite differences of the dielectric matrix
disp = np.array([0.0, 0.0, 0.0005])
norm_disp = np.linalg.norm(disp)
new_options = options

new_options["prefix"] = new_options["prefix"] + "-atm1_x_p"
new_options["pos_al"] = (np.array(options["pos_al"])+disp).tolist()
run_command(pw_command, pw_input.format(**new_options), "pw_1xp")
run_command(ph_command, ph_epsil.format(**new_options), "ph-epsil_1xp")

epsil_p = read_epsil("ph-epsil_1xp.out")

# The diagonal terms vanish due to symmetry in the finite difference 
epsil_p[0,0] = 0
epsil_p[1,1] = 0
epsil_p[2,2] = 0

n = options["k_points"]

# os.renames("./ph-epsil_1xp.out", f"./backup/{n}/ph-epsil_1xp.out")

raman_tensor = epsil_p/norm_disp/(4.0*np.pi) # 1/Angstrom

with open('./dielectrics', 'a+') as handle:
	handle.write(str(raman_tensor))
	handle.write('\n')
