from __future__ import annotations

from aiida import orm, load_profile
from aiida.plugins import WorkflowFactory
from aiida.engine import submit

load_profile()
PhBaseWorkChain = WorkflowFactory('quantumespresso.ph.base')


def main(identifier: int | str = '87a4f51f-72c7-40b3-8cf1-8573f6761fb1') -> None:
    """Launch a PhBaseWorkChain.
    
    :param identifier: identifier of the a PwBaseWorkChain node finished smoothly.
    """
    code = orm.Code.get_from_string('ph_7.1@localhost')
    parent_folder = orm.load_node(identifier).outputs.remote_folder
    builder = PhBaseWorkChain.get_builder()

    builder.clean_workdir = orm.Bool(False)
    builder.ph.parent_folder = parent_folder
    builder.ph.code = code
    builder.ph.parameters = orm.Dict({
        'INPUTPH': {
            'tr2_ph' : 1.0e-18,
            'trans': False,
            'epsil' : True,
            'lraman': True,
            'elop'  : True,
            'zeu'   : True,
            'zue'   : False,
            'nmix_ph': 8,
        }
    })

    qpoints = orm.KpointsData()
    qpoints.set_kpoints_mesh([1,1,1])
    builder.ph.qpoints = qpoints
    
    builder.ph.metadata.options = {
        'max_wallclock_seconds': 20*60*60,
        'resources': {
            'num_machines': 1,
            'num_mpiprocs_per_machine': 8,
        },
    }
    
    calc = submit(builder)
    print(f"# {calc.pk}")


if __name__ == "__main__":
    """Run the script."""
    main()

