from aiida import load_profile
from aiida.plugins import WorkflowFactory
from aiida.orm import *
from aiida.engine import submit

from aiida_quantumespresso.common.types import ElectronicType

from pathlib import Path

load_profile() 
WorkChain = WorkflowFactory('quantumespresso.pw.relax')

# ====================== LOOK HERE ================================== #
filename = 'relax'
structure_pk = '624e1ea1-ca12-4d9b-9daf-1d1017fc939a'
group_label = 'AlAs'
filepath = f'./{filename}.yml'
# =================================================================== #
print(f'Running with yaml configuration from: {filename} ...')


def main():
    """Submit WorkChain using overrides from a yaml file."""
    code = load_code('pw_7.2@lesum-hq')
    structure = load_node(structure_pk)
    
    args = (code, structure,'precise')
    kwargs = {'electronic_type': ElectronicType.INSULATOR}

    builder = WorkChain.get_builder_from_protocol(*args, overrides=Path(filepath), **kwargs)
    builder.pop('base_final_scf')
    calc = submit(builder)
    print(f'Workchain launched with PK< {calc.pk} >')


if __name__ == '__main__':
    main()
